<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:date="http://exslt.org/dates-and-times" extension-element-prefixes="date" exclude-result-prefixes="date">
	<xsl:output method="html"/>
	<xsl:template name="DurationDisplay">
		<xsl:param name="longdate"/>
		<xsl:variable name="seconds" select="(number($longdate) mod 60000) div 1000.0"/>
		<xsl:variable name="minutes" select="floor((number($longdate) div 60000) mod 60)"/>
		<xsl:variable name="hours" select="floor((number($longdate) div 3600000) mod 24)"/>
		<xsl:variable name="days" select="floor(number($longdate) div 86400000)"/>
		<xsl:value-of select="concat(format-number($days, '#0'), 'd', format-number($hours, '#0'), 'h', format-number($minutes, '#0'), 'm', $seconds, 's')"/>
	</xsl:template>
	<xsl:key name="ClientClassName" match="/javaprssrvr/clients/clientrcv" use="class/@name"/>
	<xsl:key name="NotTCPClientKey" match="/javaprssrvr/clients/clientrcv" use="not(class/@name = 'TCPClientRcv' or class/@name = 'RemoteServer' or class/@name = 'UpstreamClientRcv')"/>
	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:value-of select="javaprssrvr/dupeprocessor/servercall"/> Status Page</title>
				<meta content="noindex,nofollow" name="robots"/>
			</head>
			<body bgColor="#606060">
				<center>
					<table bgColor="#d0d0d0" border="2">
						<thead>
							<tr align="center" bgColor="#ffd700">
								<th colspan="2" align="center">
									<xsl:value-of select="javaprssrvr/@name"/>&#xA0;
									<xsl:value-of select="javaprssrvr/@version"/>
									<xsl:value-of select="javaprssrvr/@revision"/>
									<br/>Copyright &#xA9;
                                                        		<xsl:value-of select="date:year(date:date-time())"/>
									- Peter Loveall AE5PL
								</th>
							</tr>
						</thead>
						<tbody>
							<tr align="center" bgColor="#909090">
								<th colspan="2" align="center">
                                                        		<xsl:value-of select="date:date-time()"/>
								</th>
							</tr>
							<tr align="right">
								<td align="left">Server ID</td>
								<td>
									<xsl:value-of select="javaprssrvr/dupeprocessor/servercall"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">OS</td>
								<td>
									<xsl:value-of select="javaprssrvr/java/os"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">JVM</td>
								<td>
									<xsl:value-of select="javaprssrvr/java/jre"/>
									<br/>
									<xsl:value-of select="javaprssrvr/java/jre/@specversion"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Up Time</td>
								<td>
									<xsl:call-template name="DurationDisplay">
										<xsl:with-param name="longdate" select="javaprssrvr/java/time/up/@millis"/>
									</xsl:call-template>
								</td>
							</tr>
							<tr align="right">
								<td colspan="2" bgColor="#909090"/>
							</tr>
							<tr align="center">
								<td colspan="2">Memory</td>
							</tr>
							<tr align="right">
								<td align="left">Heap Current</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/java/memory/heap/@used, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Heap Before GC</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/gctask/@heapbefore, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Heap After GC</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/gctask/@heapafter, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td colspan="2" bgColor="#909090"/>
							</tr>
							<tr align="right">
								<td align="left">TCP Bytes In</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/clients/rcvdtotals/@bytes, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">UDP Bytes In</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/clients/rcvdtotals/udp/@bytes, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Bytes In</td>
								<td>
									<xsl:value-of select="format-number(number(javaprssrvr/clients/rcvdtotals/@bytes) + number(javaprssrvr/clients/rcvdtotals/udp/@bytes), '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Average bps In</td>
								<td>
									<xsl:value-of select="format-number((number(javaprssrvr/clients/rcvdtotals/@bytes) + number(javaprssrvr/clients/rcvdtotals/udp/@bytes)) * 10000 div number(javaprssrvr/java/time/up/@millis), '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">TCP Bytes Out</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/clients/xmtdtotals/@bytes, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">UDP Bytes Out</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/clients/xmtdtotals/udp/@bytes, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Bytes Out</td>
								<td>
									<xsl:value-of select="format-number(number(javaprssrvr/clients/xmtdtotals/@bytes) + number(javaprssrvr/clients/xmtdtotals/udp/@bytes), '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Average bps Out</td>
								<td>
									<xsl:value-of select="format-number((number(javaprssrvr/clients/xmtdtotals/@bytes) + number(javaprssrvr/clients/xmtdtotals/udp/@bytes)) * 10000 div number(javaprssrvr/java/time/up/@millis), '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td colspan="2" bgColor="#909090"/>
							</tr>
							<tr align="right">
								<td align="left">Total Valid Packets</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/goodpackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Duplicate Packets</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/duplicatepackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Rejected Packets</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/blockedpackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Looped Packets</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/loopedpackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Packets Processed</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/goodpackets/@packets + javaprssrvr/dupeprocessor/duplicatepackets/@packets + javaprssrvr/dupeprocessor/blockedpackets/@packets + javaprssrvr/dupeprocessor/loopedpackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td colspan="2" bgColor="#909090"/>
							</tr>
							<tr align="right">
								<td align="left">Total Clients</td>
								<td>
									<xsl:value-of select="javaprssrvr/clients/@total"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Current Clients</td>
								<td>
									<xsl:value-of select="javaprssrvr/clients/@current"/>
								</td>
							</tr>
						</tbody>
					</table>
					<xsl:for-each select="javaprssrvr/dupeprocessor/serveradjuncts">
						<xsl:choose>
							<xsl:when test="filteraprs">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="filteraprs/class/package/@title"/>
												<br/>
												<xsl:value-of select="filteraprs/class/package/@version"/>
												<xsl:value-of select="filteraprs/class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">IGates</td>
											<td align="right">
												<xsl:value-of select="filteraprs/igates/@size"/>
											</td>
										</tr>
										<tr>
											<td align="left">Non-posit WX</td>
											<td align="right">
												<xsl:value-of select="filteraprs/nonpositweatherstations/@size"/>
											</td>
										</tr>
										<tr>
											<td align="left">Stations with Posits</td>
											<td align="right">
												<xsl:value-of select="filteraprs/stationswithposits/@size"/>
											</td>
										</tr>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">Cached Filters</th>
										</tr>
										<tr>
											<td align="left">Range</td>
											<td align="right">
												<xsl:value-of select="filteraprs/cachesize/@range"/>
											</td>
										</tr>
										<tr>
											<td align="left">Friend</td>
											<td align="right">
												<xsl:value-of select="filteraprs/cachesize/@friend"/>
											</td>
										</tr>
										<tr>
											<td align="left">Area</td>
											<td align="right">
												<xsl:value-of select="filteraprs/cachesize/@area"/>
											</td>
										</tr>
									</tbody>
								</table>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
					<xsl:for-each select="key('NotTCPClientKey', 'true')">
						<xsl:sort select="class/@name"/>
						<xsl:sort select="login/callssid"/>
						<xsl:choose>
							<xsl:when test="class/@name = 'CQGate'">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="class/package/@title"/>
												<br/>
												<xsl:value-of select="class/package/@version"/>
												<xsl:value-of select="class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">Station Call</td>
											<td align="center">
												<xsl:value-of select="login/callssid"/>
											</td>
										</tr>
										<tr align="center" bgColor="#909090">
											<th>Group</th>
											<th>Members</th>
										</tr>
										<xsl:for-each select="cqgate/groups/group">
											<xsl:sort select="@name"/>
											<tr align="center">
												<td>
													<xsl:value-of select="@name"/>
												</td>
												<td align="right">
													<xsl:value-of select="format-number(@members, '#,##0')"/>
												</td>
											</tr>
										</xsl:for-each>
									</tbody>
								</table>
							</xsl:when>
							<xsl:when test="class/@name = 'DBGate'">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="class/package/@title"/>
												<br/>
												<xsl:value-of select="class/package/@version"/>
												<xsl:value-of select="class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">Station Call</td>
											<td align="center">
												<xsl:value-of select="login/callssid"/>
											</td>
										</tr>
										<xsl:if test="clientxmt/adjuncts/filteraprsclient/filter">
											<tr align="center">
												<td colspan="2">
													<xsl:value-of select="clientxmt/adjuncts/filteraprsclient/filter"/>
												</td>
											</tr>
										</xsl:if>
										<tr align="center">
											<td align="left">JDBC Driver</td>
											<td>
												<xsl:value-of select="jdbcdriver"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">JDBC Driver Version</td>
											<td>
												<xsl:value-of select="jdbcdriver/@version"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">JDBC Compliant</td>
											<td>
												<xsl:value-of select="jdbcdriver/@compliant"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Rows Inserted</td>
											<td align="right">
												<xsl:value-of select="format-number(rows/@inserted, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Rows Updated</td>
											<td align="right">
												<xsl:value-of select="format-number(rows/@updated, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Nonposit WX Packets</td>
											<td align="right">
												<xsl:value-of select="format-number(nonpositwxpackets, '#,##0')"/>
											</td>
										</tr>
									</tbody>
								</table>
							</xsl:when>
							<xsl:when test="class/@name = 'EmailGate'">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="class/package/@title"/>
												<br/>
												<xsl:value-of select="class/package/@version"/>
												<xsl:value-of select="class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">Station Call</td>
											<td align="center">
												<xsl:value-of select="login/callssid"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Email Address</td>
											<td>
												<xsl:value-of select="emailgate/srvremailaddr"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Emails Sent</td>
											<td align="right">
												<xsl:value-of select="format-number(emailgate/emails/@sent, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Valid Emails Received</td>
											<td align="right">
												<xsl:value-of select="format-number(emailgate/emails/received/@valid, '#,##0')"/>
											</td>
										</tr>
									</tbody>
								</table>
							</xsl:when>
							<xsl:when test="class/@name = 'WhoIsGate'">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="class/package/@title"/>
												<br/>
												<xsl:value-of select="class/package/@version"/>
												<xsl:value-of select="class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">Station Call</td>
											<td align="center">
												<xsl:value-of select="login/callssid"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">QRZ.com Provider</td>
											<td>
												<xsl:value-of select="whois/lookups/qrzcom/@server"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Lookups Found</td>
											<td align="right">
												<xsl:value-of select="format-number(whois/lookups/@found, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Full Lookups Found</td>
											<td align="right">
												<xsl:value-of select="format-number(whois/lookups/@fullfound, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Lookups Not Found</td>
											<td align="right">
												<xsl:value-of select="format-number(whois/lookups/@notfound, '#,##0')"/>
											</td>
										</tr>
									</tbody>
								</table>
							</xsl:when>
							<xsl:when test="class/@name = 'ObjectGenerator'">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="class/package/@title"/>
												<br/>
												<xsl:value-of select="class/package/@version"/>
												<xsl:value-of select="class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">Station Call</td>
											<td align="center">
												<xsl:value-of select="login/callssid"/>
											</td>
										</tr>
										<tr align="center" bgColor="#909090">
											<th colspan="2">Object Name</th>
										</tr>
										<xsl:for-each select="objects/object">
											<xsl:sort select="."/>
											<tr align="center">
												<td colspan="2">
													<xsl:value-of select="."/>
												</td>
											</tr>
										</xsl:for-each>
									</tbody>
								</table>
							</xsl:when>
							<xsl:when test="class/@name = 'APRSIGate'">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="class/package/@title"/>
												<br/>
												<xsl:value-of select="class/package/@version"/>
												<xsl:value-of select="class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">Station Call</td>
											<td align="center">
												<xsl:value-of select="login/callssid"/>
											</td>
										</tr>
										<xsl:if test="clientxmt/adjuncts/filteraprsclient/filter">
											<tr align="center">
												<td colspan="2">
													<xsl:value-of select="clientxmt/adjuncts/filteraprsclient/filter"/>
												</td>
											</tr>
										</xsl:if>
										<tr align="center">
											<td align="left">Serial Interface</td>
											<td>
												<xsl:value-of select="serialinterface"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Direct Stations</td>
											<td align="right">
												<xsl:value-of select="format-number(stations/@direct, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Local Stations</td>
											<td align="right">
												<xsl:value-of select="format-number(stations/@local, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Packets Sent to APRS-IS</td>
											<td align="right">
												<xsl:value-of select="format-number(rcvdfrom/@packets, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Packets Sent to RF</td>
											<td align="right">
												<xsl:value-of select="format-number(clientxmt/sentto/@packets, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Messages Gated to RF</td>
											<td align="right">
												<xsl:value-of select="format-number(messagesgatedtorf, '#,##0')"/>
											</td>
										</tr>
									</tbody>
								</table>
							</xsl:when>
							<xsl:when test="class/@name = 'WXNowGen'">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="class/package/@title"/>
												<br/>
												<xsl:value-of select="class/package/@version"/>
												<xsl:value-of select="class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">Station Call</td>
											<td align="center">
												<xsl:value-of select="login/callssid"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Weather Packets Generated</td>
											<td align="right">
												<xsl:value-of select="format-number(rcvdfrom/@packets, '#,##0')"/>
											</td>
										</tr>
									</tbody>
								</table>
							</xsl:when>
							<xsl:when test="class/@name = 'NSRDigi'">
								<p>&#xA0;</p>
								<table bgColor="#d0d0d0" border="2">
									<thead>
										<tr align="center" bgColor="#ffd700">
											<th colspan="2" align="center">
												<xsl:value-of select="class/package/@title"/>
												<br/>
												<xsl:value-of select="class/package/@version"/>
												<xsl:value-of select="class/package/@revision"/>
											</th>
										</tr>
									</thead>
									<tbody>
										<tr>
											<td align="left">Digipeater Call</td>
											<td align="center">
												<xsl:value-of select="nsrdigi/@callsign"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Serial Interface</td>
											<td>
												<xsl:value-of select="serialinterface"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Packets Processed</td>
											<td align="right">
												<xsl:value-of select="format-number(nsrdigi/packets/@total, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Packets Digipeated</td>
											<td align="right">
												<xsl:value-of select="format-number(nsrdigi/packets/@digied, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Long Paths</td>
											<td align="right">
												<xsl:value-of select="format-number(nsrdigi/longpaths, '#,##0')"/>
											</td>
										</tr>
										<tr align="center">
											<td align="left">Recently Heard</td>
											<td align="right">
												<xsl:value-of select="format-number(nsrdigi/recentlyheard, '#,##0')"/>
											</td>
										</tr>
									</tbody>
								</table>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
					<xsl:for-each select="javaprssrvr/serialinterfaces/serialintf">
						<xsl:sort select="@name"/>
						<p>&#xA0;</p>
						<table bgColor="#d0d0d0" border="2">
							<thead>
								<tr align="center" bgColor="#ffd700">
									<th colspan="2" align="center">
										<xsl:value-of select="class/package/@title"/>
										<br/>
										<xsl:value-of select="class/package/@version"/>
										<xsl:value-of select="class/package/@revision"/>
									</th>
								</tr>
							</thead>
							<tbody>
								<tr>
									<td align="left">IntfName</td>
									<td align="center">
										<xsl:value-of select="@name"/>
									</td>
								</tr>
								<tr align="center">
									<td align="left">Connected</td>
									<td align="center">
										<xsl:value-of select="connected"/>
									</td>
								</tr>
								<xsl:if test="commport">
									<tr align="center">
										<td align="left">Com Port</td>
										<td align="center">
											<xsl:value-of select="commport/@name"/>
										</td>
									</tr>
									<tr align="center">
										<td align="left">Port Settings</td>
										<td align="center">
											<xsl:value-of select="commport/portsettings"/>
										</td>
									</tr>
								</xsl:if>
								<xsl:if test="ax25port">
									<tr align="center">
										<td align="left">axport Name</td>
										<td align="center">
											<xsl:value-of select="ax25port"/>
										</td>
									</tr>
								</xsl:if>
							</tbody>
						</table>
					</xsl:for-each>

					<p>&#xA0;</p>
					<table bgColor="#d0d0d0" border="2">
						<thead>
							<tr align="center" bgColor="#ffd700">
								<th colspan="2" align="center">Available Ports</th>
							</tr>
							<tr align="center" bgColor="#909090">
								<th>Port Number</th>
								<th>Description</th>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="javaprssrvr/listenerports/portlistener">
								<xsl:sort select="description/@Port" data-type="number"/>
								<xsl:if test="description">
									<tr align="center">
										<td>
											<xsl:value-of select="description/@Port"/>
										</td>
										<td>
											<xsl:value-of select="description"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</tbody>
					</table>
					<xsl:if test="count(key('ClientClassName', 'RemoteServer'))&gt;0">
						<p>&#xA0;</p>
						<table bgColor="#d0d0d0" border="2">
							<thead>
								<tr align="center" bgColor="#ffd700">
									<th colSpan="16">Remote Peer Servers</th>
								</tr>
								<tr align="center" bgColor="#909090">
									<th>Client IP</th>
									<th>Callsign</th>
									<th>Packets
										<br/>Rcvd</th>
									<th>Packets
										<br/>Sent</th>
									<th>Bytes
										<br/>Rcvd</th>
									<th>Bytes
										<br/>Sent</th>
									<th>Rcv
										<br/>bps</th>
									<th>Send
										<br/>bps</th>
									<th>Last
										<br/>Packet In</th>
								</tr>
							</thead>
							<tbody>
								<xsl:for-each select="key('ClientClassName', 'RemoteServer')">
									<xsl:sort select="login/callssid"/>
									<tr align="right">
										<td align="center">
											<a href="http://{remoteserver}:14501">
												<xsl:value-of select="remoteserver"/>
											</a>
										</td>
										<td align="center">
											<xsl:value-of select="login/callssid"/>
										</td>
										<td>
											<xsl:value-of select="format-number(rcvdfrom/udp/@packets, '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/udp/@packets, '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number(rcvdfrom/udp/@bytes, '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/udp/@bytes, '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number((number(rcvdfrom/@bytes) + number(rcvdfrom/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number((number(clientxmt/sentto/@bytes) + number(clientxmt/sentto/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:choose>
												<xsl:when test="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc) &gt;= 0">
													<xsl:call-template name="DurationDisplay">
														<xsl:with-param name="longdate" select="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc)"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>0d0h0m0s</xsl:otherwise>
											</xsl:choose>
										</td>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>
					<xsl:if test="count(key('NotTCPClientKey', 'true'))&gt;0">
						<p>&#xA0;</p>
						<table bgColor="#d0d0d0" border="2">
							<thead>
								<tr align="center" bgColor="#ffd700">
									<th colSpan="16">Internal Clients</th>
								</tr>
								<tr align="center" bgColor="#909090">
									<th>Callsign</th>
									<th>Verified</th>
									<th>Software</th>
									<th>SA Setting</th>
									<th>Packets
										<br/>Rcvd</th>
									<th>Packets
										<br/>Sent</th>
									<th>Bytes
										<br/>Rcvd</th>
									<th>Bytes
										<br/>Sent</th>
									<th>Rcv
										<br/>bps</th>
									<th>Send
										<br/>bps</th>
									<th>Last
										<br/>Packet In</th>
								</tr>
							</thead>
							<tbody>
								<xsl:for-each select="key('NotTCPClientKey', 'true')">
									<xsl:sort select="class/@name"/>
									<xsl:sort select="login/callssid"/>
									<tr align="right">
										<td align="center">
											<xsl:choose>
												<xsl:when test="not(login) and not(networkinterface)">Non-APRS</xsl:when>
												<xsl:when test="not(login)">No Login</xsl:when>
												<xsl:when test="contains(login/callssid, '-')">
													<a href="http://www.jfindu.net/lh/{substring-before(login/callssid, '-')}">
														<xsl:value-of select="login/callssid"/>
													</a>
												</xsl:when>
												<xsl:otherwise>
													<a href="http://www.jfindu.net/lh/{login/callssid}">
														<xsl:value-of select="login/callssid"/>
													</a>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td align="center">
											<xsl:value-of select="login/callssid/@verified"/>
										</td>
										<td align="center">
											<xsl:value-of select="login/software"/>&#xA0;
											<xsl:value-of select="login/software/@version"/>
										</td>
										<td align="center">
											<xsl:for-each select="clientxmt/adjuncts">
												<xsl:if test="filteraprsclient/filter">
													<xsl:value-of select="filteraprsclient/filter"/>
												</xsl:if>
											</xsl:for-each>
										</td>
										<td>
											<xsl:value-of select="format-number(rcvdfrom/@packets, '#,##0')"/>
											<xsl:if test="rcvdfrom/udp/@packets &gt; 0">
												<br/>
												<xsl:value-of select="format-number(rcvdfrom/udp/@packets, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/@packets, '#,##0')"/>
											<xsl:if test="clientxmt/sentto/udp/@packets &gt; 0">
												<br/>
												<xsl:value-of select="format-number(clientxmt/sentto/udp/@packets, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(number(rcvdfrom/@bytes), '#,##0')"/>
											<xsl:if test="rcvdfrom/udp/@bytes &gt; 0">
												<br/>
												<xsl:value-of select="format-number(rcvdfrom/udp/@bytes, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/@bytes, '#,##0')"/>
											<xsl:if test="clientxmt/sentto/udp/@bytes &gt; 0">
												<br/>
												<xsl:value-of select="format-number(clientxmt/sentto/udp/@bytes, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number((number(rcvdfrom/@bytes) + number(rcvdfrom/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number((number(clientxmt/sentto/@bytes) + number(clientxmt/sentto/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:choose>
												<xsl:when test="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc) &gt;= 0">
													<xsl:call-template name="DurationDisplay">
														<xsl:with-param name="longdate" select="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc)"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>0d0h0m0s</xsl:otherwise>
											</xsl:choose>
										</td>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>
					<xsl:if test="count(key('ClientClassName', 'UpstreamClientRcv'))&gt;0">
						<p>&#xA0;</p>
						<table bgColor="#d0d0d0" border="2">
							<thead>
								<tr align="center" bgColor="#ffd700">
									<th colSpan="16">Upstream Servers</th>
								</tr>
								<tr align="center" bgColor="#909090">
									<th>Client IP</th>
									<th>Callsign</th>
									<th>Verified</th>
									<th>Software</th>
									<th>Connected</th>
									<th>Packets
										<br/>Rcvd</th>
									<th>Packets
										<br/>Sent</th>
									<th>Bytes
										<br/>Rcvd</th>
									<th>Bytes
										<br/>Sent</th>
									<th>Rcv
										<br/>bps</th>
									<th>Send
										<br/>bps</th>
									<th>Last
										<br/>Packet In</th>
								</tr>
							</thead>
							<tbody>
								<xsl:for-each select="key('ClientClassName', 'UpstreamClientRcv')">
									<xsl:sort select="time/connect/@utc" data-type="number"/>
									<tr align="right">
										<td align="center">
											<xsl:choose>
												<xsl:when test="client">
													<a href="http://{client}:14501">
														<xsl:value-of select="client"/>
													</a>
												</xsl:when>
												<xsl:when test="remoteserver">
													<a href="http://{remoteserver}:14501">
														<xsl:value-of select="remoteserver"/>
													</a>
												</xsl:when>
												<xsl:otherwise>Internal</xsl:otherwise>
											</xsl:choose>
										</td>
										<td align="center">
											<xsl:choose>
												<xsl:when test="not(login) and not(networkinterface)">Non-APRS</xsl:when>
												<xsl:when test="not(login)">No Login</xsl:when>
												<xsl:when test="contains(login/callssid, '-')">
													<a href="http://www.jfindu.net/lh/{substring-before(login/callssid, '-')}">
														<xsl:value-of select="login/callssid"/>
													</a>
												</xsl:when>
												<xsl:otherwise>
													<a href="http://www.jfindu.net/lh/{login/callssid}">
														<xsl:value-of select="login/callssid"/>
													</a>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td align="center">
											<xsl:value-of select="login/callssid/@verified"/>
										</td>
										<td align="center">
											<xsl:value-of select="login/software"/>&#xA0;
											<xsl:value-of select="login/software/@version"/>
										</td>
										<td align="center">
											<xsl:choose>
												<xsl:when test="/javaprssrvr/java/time/current/@utc - time/connect/@utc &gt;= 0">
													<xsl:call-template name="DurationDisplay">
														<xsl:with-param name="longdate" select="/javaprssrvr/java/time/current/@utc - time/connect/@utc"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>0d0h0m0s</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:value-of select="format-number(rcvdfrom/@packets, '#,##0')"/>
											<xsl:if test="rcvdfrom/udp/@packets &gt; 0">
												<br/>
												<xsl:value-of select="format-number(rcvdfrom/udp/@packets, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/@packets, '#,##0')"/>
											<xsl:if test="clientxmt/sentto/udp/@packets &gt; 0">
												<br/>
												<xsl:value-of select="format-number(clientxmt/sentto/udp/@packets, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(number(rcvdfrom/@bytes), '#,##0')"/>
											<xsl:if test="rcvdfrom/udp/@bytes &gt; 0">
												<br/>
												<xsl:value-of select="format-number(rcvdfrom/udp/@bytes, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/@bytes, '#,##0')"/>
											<xsl:if test="clientxmt/sentto/udp/@bytes &gt; 0">
												<br/>
												<xsl:value-of select="format-number(clientxmt/sentto/udp/@bytes, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number((number(rcvdfrom/@bytes) + number(rcvdfrom/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number((number(clientxmt/sentto/@bytes) + number(clientxmt/sentto/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:choose>
												<xsl:when test="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc) &gt;= 0">
													<xsl:call-template name="DurationDisplay">
														<xsl:with-param name="longdate" select="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc)"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>0d0h0m0s</xsl:otherwise>
											</xsl:choose>
										</td>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>
					<p>&#xA0;</p>
					<table bgColor="#d0d0d0" border="2">
						<thead>
							<tr align="center" bgColor="#ffd700">
								<th colSpan="16">Remote Clients</th>
							</tr>
							<tr align="center" bgColor="#909090">
								<th>Port</th>
								<th>Client IP</th>
								<th>Callsign</th>
								<th>Verified</th>
								<th>Software</th>
								<th>SA Setting</th>
								<th>Connected</th>
								<th>Packets
									<br/>Rcvd</th>
								<th>Packets
									<br/>Sent</th>
								<th>Bytes
									<br/>Rcvd</th>
								<th>Bytes
									<br/>Sent</th>
								<th>Rcv
									<br/>bps</th>
								<th>Send
									<br/>bps</th>
								<th>Last
									<br/>Packet In</th>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="key('ClientClassName', 'TCPClientRcv')">
								<xsl:sort select="time/connect/@utc" data-type="number"/>
								<tr align="right">
									<td align="center">
										<xsl:if test="networkinterface and networkinterface/@port &gt; 0 and not(remoteserver)">
											<xsl:value-of select="networkinterface/@port"/>
										</xsl:if>
									</td>
									<td align="center">
										<xsl:choose>
											<xsl:when test="client">
												<a href="http://{client}:14501">
													<xsl:value-of select="client"/>
												</a>
											</xsl:when>
											<xsl:when test="remoteserver">
												<a href="http://{remoteserver}:14501">
													<xsl:value-of select="remoteserver"/>
												</a>
											</xsl:when>
											<xsl:otherwise>Internal</xsl:otherwise>
										</xsl:choose>
									</td>
									<td align="center">
										<xsl:choose>
											<xsl:when test="not(login) and not(networkinterface)">Non-APRS</xsl:when>
											<xsl:when test="not(login)">No Login</xsl:when>
											<xsl:when test="contains(login/callssid, '-')">
												<a href="http://www.jfindu.net/lh/{substring-before(login/callssid, '-')}">
													<xsl:value-of select="login/callssid"/>
												</a>
											</xsl:when>
											<xsl:otherwise>
												<a href="http://www.jfindu.net/lh/{login/callssid}">
													<xsl:value-of select="login/callssid"/>
												</a>
											</xsl:otherwise>
										</xsl:choose>
									</td>
									<td align="center">
										<xsl:value-of select="login/callssid/@verified"/>
									</td>
									<td align="center">
										<xsl:value-of select="login/software"/>&#xA0;
										<xsl:value-of select="login/software/@version"/>
									</td>
									<td align="center">
										<xsl:for-each select="clientxmt/adjuncts">
											<xsl:if test="filteraprsclient/filter">
												<xsl:value-of select="filteraprsclient/filter"/>
											</xsl:if>
										</xsl:for-each>
									</td>
									<td align="center">
										<xsl:choose>
											<xsl:when test="/javaprssrvr/java/time/current/@utc - time/connect/@utc &gt;= 0">
												<xsl:call-template name="DurationDisplay">
													<xsl:with-param name="longdate" select="/javaprssrvr/java/time/current/@utc - time/connect/@utc"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>0d0h0m0s</xsl:otherwise>
										</xsl:choose>
									</td>
									<td>
										<xsl:value-of select="format-number(rcvdfrom/@packets, '#,##0')"/>
										<xsl:if test="rcvdfrom/udp/@packets &gt; 0">
											<br/>
											<xsl:value-of select="format-number(rcvdfrom/udp/@packets, '#,##0')"/>u</xsl:if>
									</td>
									<td>
										<xsl:value-of select="format-number(clientxmt/sentto/@packets, '#,##0')"/>
										<xsl:if test="clientxmt/sentto/udp/@packets &gt; 0">
											<br/>
											<xsl:value-of select="format-number(clientxmt/sentto/udp/@packets, '#,##0')"/>u</xsl:if>
									</td>
									<td>
										<xsl:value-of select="format-number(number(rcvdfrom/@bytes), '#,##0')"/>
										<xsl:if test="rcvdfrom/udp/@bytes &gt; 0">
											<br/>
											<xsl:value-of select="format-number(rcvdfrom/udp/@bytes, '#,##0')"/>u</xsl:if>
									</td>
									<td>
										<xsl:value-of select="format-number(clientxmt/sentto/@bytes, '#,##0')"/>
										<xsl:if test="clientxmt/sentto/udp/@bytes &gt; 0">
											<br/>
											<xsl:value-of select="format-number(clientxmt/sentto/udp/@bytes, '#,##0')"/>u</xsl:if>
									</td>
									<td>
										<xsl:value-of select="format-number((number(rcvdfrom/@bytes) + number(rcvdfrom/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
									</td>
									<td>
										<xsl:value-of select="format-number((number(clientxmt/sentto/@bytes) + number(clientxmt/sentto/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
									</td>
									<td>
										<xsl:choose>
											<xsl:when test="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc) &gt;= 0">
												<xsl:call-template name="DurationDisplay">
													<xsl:with-param name="longdate" select="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc)"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>0d0h0m0s</xsl:otherwise>
										</xsl:choose>
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</center>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet><!-- Stylus Studio meta-information - (c) 2004-2009. Progress Software Corporation. All rights reserved.

<metaInformation>
	<scenarios>
		<scenario default="yes" name="detail.xml" userelativepaths="yes" externalpreview="no" url="detail.xml" htmlbaseurl="" outputurl="" processortype="jaxp" useresolver="no" profilemode="0" profiledepth="" profilelength="" urlprofilexml=""
		          commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext="" validateoutput="no" validator="internal" customvalidator="">
			<advancedProp name="sInitialMode" value=""/>
			<advancedProp name="schemaCache" value="||"/>
			<advancedProp name="bXsltOneIsOkay" value="true"/>
			<advancedProp name="bSchemaAware" value="false"/>
			<advancedProp name="bGenerateByteCode" value="false"/>
			<advancedProp name="bXml11" value="false"/>
			<advancedProp name="iValidation" value="0"/>
			<advancedProp name="bExtensions" value="true"/>
			<advancedProp name="iWhitespace" value="0"/>
			<advancedProp name="sInitialTemplate" value=""/>
			<advancedProp name="bTinyTree" value="true"/>
			<advancedProp name="xsltVersion" value="2.0"/>
			<advancedProp name="bWarnings" value="true"/>
			<advancedProp name="bUseDTD" value="false"/>
			<advancedProp name="iErrorHandling" value="fatal"/>
		</scenario>
	</scenarios>
	<MapperMetaTag>
		<MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no">
			<SourceSchema srcSchemaPath="detail.xml" srcSchemaRoot="javaprssrvr" AssociatedInstance="" loaderFunction="document" loaderFunctionUsesURI="no"/>
		</MapperInfo>
		<MapperBlockPosition>
			<template match="/"></template>
			<template name="javaUTCDateTime">
				<block path="xsl:value-of" x="99" y="0"/>
				<block path="xsl:value-of[1]" x="139" y="0"/>
			</template>
		</MapperBlockPosition>
		<TemplateContext></TemplateContext>
		<MapperFilter side="source"></MapperFilter>
	</MapperMetaTag>
</metaInformation>
-->